This package was tested under:
  
    - **Windows 10** 
       - with |miniconda_link| Python 2.7 distribution
    - **Ubuntu 14.04.5 LTS** 
       - with Python 2.7 compiled from source (|python_link|)
       - with Python 3.6 compiled from source (|python_link|)
    - **MacOS Sierra**
       - with |miniconda_link| Python 2.7 distribution
       

Some installations of the |mayavi_link| (>= 4.5.0) package on various systems 
with Python 2 or 3 are described in |python-mayavi_link| dedicated web page.